@@ -98,7 +98,7 @@ def deliver_data(job_uuid, bucket_name, file_pattern, platform_name, destination
                 destination=destination, platform_name=platform_name, segments=segment_mapping, local_path=local_path,
                 chunk_number=chunk_number, start_time=start_time, id_types=id_types, operations=operations
             )
-        except RetryError as e:
+        except Exception as e:
             success = False
             if get_settings()['environment'] not in {'qa', 'prod'}:
                 raise e
@@ -115,10 +115,10 @@ def deliver_data(job_uuid, bucket_name, file_pattern, platform_name, destination
 
     rows = compose_integration_logs(job_uuid, segments, file_pattern, int(end_time.timestamp()), id_types, operations,
                                     'completed')
+    if '*' in file_pattern:
+        log_integration(rows)
 
-    log_integration(rows)
-
-    return close_delivery(job_uuid=job_uuid)
+    return dict(job_uuid=job_uuid, file_pattern=file_pattern, chunk_start_number=chunk_start_number)
 
 
 def log_chunk_delivery(success, start, destination, chunk_number, segments, job_uuid, platform_name, error_type=None):
